==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/sk/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 bodov)":  "1",
		"2 (10 bodov)": "2",
		"3 (12 bodov)": "3",
		"4 (14 bodov)": "4",
		"5 (18 bodov)": "5",
		"6 (24 bodov)": "6",
		"7 (36 bodov)": "7"
	},

	formatblock: {
		"Hlavika 1": "h1",
		"Hlavika 2": "h2",
		"Hlavika 3": "h3",
		"Hlavika 4": "h4",
		"Hlavika 5": "h5",
		"Hlavika 6": "h6",
		"Normlny": "p",
		"Adresa": "address",
		"Formtovan": "pre"
	},

	tooltips: {
		bold:           "Hrub",
		italic:         "Kurzva",
		underline:      "Podiarknut",
		strikethrough:  "Preiarknut",
		subscript:      "Doln index",
		superscript:    "Horn index",
		justifyleft:    "Zarovna do ava",
		justifycenter:  "Vycentrova",
		justifyright:   "Zarovna do prava",
		justifyfull:    "Zarovna na obe strany",
		orderedlist:    "Zoraden zoznam",
		unorderedlist:  "Gulikov zoznam",
		outdent:        "Zmeni odsadenie",
		indent:         "Zvi odsadenie",
		forecolor:      "Farba psma",
		backcolor:      "Farba pozadia",
		horizontalrule: "Horizontlna iara",
		createlink:     "Vloi webov odkaz",
		insertimage:    "Vloi obrzok",
		insertsound:    "Vloi zvuk",
		inserttable:    "Vloi tabuku",
		htmlmode:       "Zobrazi HTML zdrojov kd",
		popupeditor:    "Zvi editor",
		about:          "O tomto editore",
		help:           "Pomoc",
		textindicator:  "Aktulny tl"
	}
};

==> openwebmail-2.30.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/sk/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 bodov)":  "1",
		"2 (10 bodov)": "2",
		"3 (12 bodov)": "3",
		"4 (14 bodov)": "4",
		"5 (18 bodov)": "5",
		"6 (24 bodov)": "6",
		"7 (36 bodov)": "7"
	},

	formatblock: {
		"Hlavika 1": "h1",
		"Hlavika 2": "h2",
		"Hlavika 3": "h3",
		"Hlavika 4": "h4",
		"Hlavika 5": "h5",
		"Hlavika 6": "h6",
		"Normlny": "p",
		"Adresa": "address",
		"Formtovan": "pre"
	},

	tooltips: {
		bold:           "Hrub",
		italic:         "Kurzva",
		underline:      "Podiarknut",
		strikethrough:  "Preiarknut",
		subscript:      "Doln index",
		superscript:    "Horn index",
		justifyleft:    "Zarovna do ava",
		justifycenter:  "Vycentrova",
		justifyright:   "Zarovna do prava",
		justifyfull:    "Zarovna na obe strany",
		insertorderedlist:    "Zoraden zoznam",
		insertunorderedlist:  "Gulikov zoznam",
		outdent:        "Zmeni odsadenie",
		indent:         "Zvi odsadenie",
		forecolor:      "Farba psma",
		hilitecolor:    "Farba pozadia",
		horizontalrule: "Horizontlna iara",
		createlink:     "Vloi webov odkaz",
		insertimage:    "Vloi obrzok",
		insertsound:    "Vloi zvuk",
		inserttable:    "Vloi tabuku",
		htmlmode:       "Zobrazi HTML zdrojov kd",
		popupeditor:    "Zvi editor",
		about:          "O tomto editore",
		showhelp:       "Pomoc",
		textindicator:  "Aktulny tl",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};
